==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/weather_status/l10n/uk.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Невідома адреса",
    "No result." : "Жодного результату.",
    "Malformed JSON data." : "Неправильні дані JSON.",
    "Error" : "Помилка",
    "Weather status" : "Прогноз погоди",
    "Weather status in your dashboard" : "Статус погоди на вашій інформаційній панелі",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Статус погоди інтегрований у програму Dashboard. Позиція користувача може бути визначена автоматично або вручну. Потім відображається прогноз на 6 годин. Цей статус також можна інтегрувати в інші місця, як-от додаток Календар.",
    "Detect location" : "Визначити місцезнаходження",
    "Set custom address" : "Встановити власну адресу",
    "Favorites" : "Улюблене",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} ясне небо пізніше сьогодні",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ясне небо",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} хмарно пізніше сьогодні",
    "{temperature} {unit} cloudy" : "{temperature} {unit} хмарно",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} гарна погода пізніше сьогодні",
    "{temperature} {unit} fair weather" : "{temperature} {unit} гарна погода",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} мінлива хмарність пізніше сьогодні",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} мінлива хмарність",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} туман пізніше сьогодні",
    "{temperature} {unit} foggy" : "{temperature} {unit} туман",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} невеликий дощ пізніше сьогодні",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} невеликий дощ",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} опадів пізніше сьогодні",
    "{temperature} {unit} rainfall" : "{temperature} {unit} опади",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} сьогодні сильний дощ",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} сильні опади",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} дощ пізніше сьогодні",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} злива",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} невеликий дощ пізніше сьогодні",
    "{temperature} {unit} light rainfall showers" : " {temperature} {unit} невеликі дощові зливи",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} сильний дощ пізніше сьогодні",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} проливні дощі",
    "More weather for {adr}" : "Більше інформації про погоду для {adr}",
    "Loading weather" : "Завантаження інформації про стан погоди",
    "Remove from favorites" : "Вилучено з улюбленого",
    "Add as favorite" : "Додати до улюблених",
    "You are not logged in." : "Ви не ввійшли до системи.",
    "There was an error getting the weather status information." : "Виникла помилка при отриманні інформації про стан погоди.",
    "No weather information found" : "Інформацію про погоду не знайдено",
    "Location not found" : "Місцезнаходження не знайдено",
    "There was an error setting the location address." : "Виникла помилка при встановленні адреси місцезнаходження.",
    "There was an error setting the location." : "Під час встановлення місцезнаходження сталася помилка.",
    "There was an error saving the mode." : "Під час збереження режиму сталася помилка.",
    "There was an error using personal address." : "Під час використання особистої адреси сталася помилка.",
    "Set location for weather" : "Встановіть місце для погоди",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Ясне небо о {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Хмарно о {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Ярмарок о {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Справжня ніч о {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Мінлива хмарність о {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Туман о {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Легкий дощ о {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Дощ о {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Сильний дощ о {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Дощ о {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Легкий дощ о {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Сильний дощ о {time}"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-28.0.6.tar.bz2: nextcloud/apps/weather_status/l10n/uk.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Невідома адреса",
    "No result." : "Жодного результату.",
    "Malformed JSON data." : "Неправильні дані JSON.",
    "Error" : "Помилка",
    "Weather status" : "Прогноз погоди",
    "Weather status in your dashboard" : "Статус погоди на вашій інформаційній панелі",
    "Detect location" : "Визначити місце розташування",
    "Set custom address" : "Встановити власну адресу",
    "Favorites" : "Із зірочкою",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} ясне небо пізніше сьогодні",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ясне небо",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} хмарно пізніше сьогодні",
    "{temperature} {unit} cloudy" : "{temperature} {unit} хмарно",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} гарна погода пізніше сьогодні",
    "{temperature} {unit} fair weather" : "{temperature} {unit} гарна погода",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} мінлива хмарність пізніше сьогодні",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} мінлива хмарність",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} туман пізніше сьогодні",
    "{temperature} {unit} foggy" : "{temperature} {unit} туман",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} невеликий дощ пізніше сьогодні",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} невеликий дощ",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} опадів пізніше сьогодні",
    "{temperature} {unit} rainfall" : "{temperature} {unit} опади",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} сьогодні сильний дощ",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} сильні опади",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} дощ пізніше сьогодні",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} злива",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} невеликий дощ пізніше сьогодні",
    "{temperature} {unit} light rainfall showers" : " {temperature} {unit} невеликі дощові зливи",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} сильний дощ пізніше сьогодні",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} проливні дощі",
    "More weather for {adr}" : "Більше інформації про погоду для {adr}",
    "Loading weather" : "Завантаження інформації про стан погоди",
    "Remove from favorites" : "Прибрати зірочку",
    "Add as favorite" : "Позначити зірочкою",
    "You are not logged in." : "Ви не ввійшли до системи.",
    "There was an error getting the weather status information." : "Виникла помилка при отриманні інформації про стан погоди.",
    "No weather information found" : "Інформацію про погоду не знайдено",
    "Location not found" : "Місце розташування не знайдено",
    "There was an error setting the location address." : "Виникла помилка при встановленні адреси розташування.",
    "There was an error setting the location." : "Під час встановлення місця розташування сталася помилка.",
    "There was an error saving the mode." : "Під час збереження режиму сталася помилка.",
    "There was an error using personal address." : "Під час використання особистої адреси сталася помилка.",
    "Set location for weather" : "Встановіть місце для погоди",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Статус погоди інтегрований до застосунку з панеллю віджетів (Dashboard). Розташування користувача може визначатися автоматично або вручну. В застосунку показується прогноз на 6 годин.\nСтатус може показуватися й інших застосунках, як-от у \"Календарі\"."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
